'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var core = require('@vue-storefront/core');
var queryString = require('query-string');
var jwt$1 = require('jsonwebtoken');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var queryString__default = /*#__PURE__*/_interopDefaultLegacy(queryString);
var jwt__default = /*#__PURE__*/_interopDefaultLegacy(jwt$1);

const BigCommerce = require('node-bigcommerce');
function client(settings) {
    return new BigCommerce(settings);
}

/**
 * Bigcommerce catalog endpoints
 */
const BigCommerceEndpoints = {
    customers: '/customers',
    products: '/catalog/products',
    review: (productId, reviewId) => `/catalog/products/${productId}/reviews/${reviewId}`,
    reviews: (productId) => `/catalog/products/${productId}/reviews`,
    validateCredentials: '/customers/validate-credentials',
    category: (categoryId) => categoryId ? `/catalog/categories/${categoryId}` : '/catalog/categories',
    categoryTree: () => '/catalog/categories/tree',
    cartItems: (cartId, itemId) => `/carts/${cartId}/items${itemId ? `/${itemId}` : ''}`,
    cart: (cartId) => (cartId ? `/carts/${cartId}` : '/carts'),
    storefrontLoginWithToken: (token) => `/login/token/${token}`,
    storefrontCurrentlyLoggedInCustomer: '/customer/current.jwt',
    formFieldValues: '/customers/form-field-values',
    addresses: '/customers/addresses',
    wishlistItems: (wishlistId, itemId) => itemId
        ? `/wishlists/${wishlistId}/items/${itemId}`
        : `/wishlists/${wishlistId}/items`,
    wishlists: (wishlistId) => wishlistId ? `/wishlists/${wishlistId}` : '/wishlists',
    orders: '/orders',
    orderProducts: (orderId) => `/orders/${orderId}/products`,
    orderShipping: (orderId) => `/orders/${orderId}/shipping_addresses`
};
var BigCommerceEndpoints$1 = BigCommerceEndpoints;

const COOKIE_KEY_CUSTOMER_DATA = 'customer-data';
const MESSAGE_LOGIN_ERROR = 'Wrong email or password';
const MESSAGE_LOGIN_TOKEN_ERROR = 'Something went wrong during the authentication. Please try again.';
const MESSAGE_INVALID_TOKEN_RESPONSE = 'Invalid token response';
const COOKIE_KEY_SHOP_SESSION_TOKEN = 'SHOP_SESSION_TOKEN';
const COOKIE_KEY_SHOPPER_PREF = 'Shopper-Pref';

async function validateCredentials(context, params) {
    checkParameters$1(params);
    return await context.client.v3.post(BigCommerceEndpoints$1.validateCredentials, params);
}
function checkParameters$1(params) {
    if (!params.email || !params.password) {
        throw new Error('Required parameters missing.');
    }
}

function getTimestampInSeconds() {
    return Math.round(Date.now() / 1000);
}
function getDateDaysLater(days) {
    const differenceInMilliseconds = days * 24 * 60 * 60 * 1000;
    return new Date(Date.now() + differenceInMilliseconds);
}

const jwt = require('jsonwebtoken');
const { v4: uuidv4 } = require('uuid');
const nodeFetch = require('node-fetch');
const fetch = require('fetch-cookie/node-fetch')(nodeFetch);
const loginCustomer = async (context, params) => {
    try {
        const validationResponse = await getValidationResponse(context, params);
        await performLogin(context, validationResponse.customer_id);
        const customerDataToken = await verifyLogin(context);
        setTokenCookie$1(context, customerDataToken);
        return validationResponse;
    }
    catch (error) {
        return {
            is_valid: false,
            errorMessage: error.message
        };
    }
};
async function getValidationResponse(context, customerCredentials) {
    const { customer_id: customerId, is_valid: isValid } = await validateCredentials(context, customerCredentials);
    if (!isValid) {
        throw { statusCode: 400, message: MESSAGE_LOGIN_ERROR };
    }
    return {
        customer_id: customerId,
        is_valid: isValid
    };
}
async function performLogin(context, customerId) {
    const ssoLoginLink = generateSsoLoginLink(context, customerId);
    const ssoResponse = await fetch(ssoLoginLink);
    if (ssoResponse?.status !== 200 || ssoResponse?.url?.includes('/login.php')) {
        throw new Error(MESSAGE_LOGIN_TOKEN_ERROR);
    }
}
async function verifyLogin(context) {
    const { config: { sdkSettings: { devtoolsAppSecret } } } = context;
    const loggedInCustomerToken = await getLoggedInCustomerToken(context);
    const decodedToken = jwt.verify(loggedInCustomerToken, devtoolsAppSecret);
    if (!decodedToken?.customer) {
        throw new Error(MESSAGE_INVALID_TOKEN_RESPONSE);
    }
    return loggedInCustomerToken;
}
function setTokenCookie$1(context, token) {
    const { config: { jwtTokenExpirationDays, secureCookies }, res } = context;
    res.cookie(COOKIE_KEY_CUSTOMER_DATA, token, {
        expires: getDateDaysLater(jwtTokenExpirationDays),
        httpOnly: secureCookies,
        secure: secureCookies,
        sameSite: secureCookies ? 'Strict' : 'Lax'
    });
}
async function getLoggedInCustomerToken(context) {
    const { config: { sdkSettings: { storeUrl, guestToken, devtoolsAppClientId } } } = context;
    const response = await fetch(queryString__default["default"].stringifyUrl({
        url: `${storeUrl}${BigCommerceEndpoints$1.storefrontCurrentlyLoggedInCustomer}`,
        query: {
            app_client_id: devtoolsAppClientId,
            ...(guestToken ? { guestTkn: guestToken } : {})
        }
    }));
    if (response?.status !== 200) {
        throw new Error(MESSAGE_INVALID_TOKEN_RESPONSE);
    }
    return await response.text();
}
function generateSsoLoginLink(context, customerId, redirectUrl) {
    const { config: { sdkSettings: { clientId, secret, storeHash, storeUrl, guestToken } } } = context;
    const dateCreated = getTimestampInSeconds();
    const payload = {
        iss: clientId,
        iat: dateCreated,
        jti: uuidv4(),
        operation: 'customer_login',
        store_hash: storeHash,
        channel_id: process.env.BIGCOMMERCE_CHANNEL_ID || '1',
        customer_id: `${customerId}`,
        ...(redirectUrl ? { redirect_to: redirectUrl } : {})
    };
    const token = jwt.sign(payload, secret, {
        algorithm: 'HS256'
    });
    return queryString__default["default"].stringifyUrl({
        url: `${storeUrl}${BigCommerceEndpoints$1.storefrontLoginWithToken(token)}`,
        query: {
            ...(guestToken ? { guestTkn: guestToken } : {})
        }
    });
}

const getCustomerIdFromCookie = async (context) => {
    const { config: { sdkSettings: { devtoolsAppSecret } }, req } = context;
    const decodedToken = jwt__default["default"].decode(req?.cookies[COOKIE_KEY_CUSTOMER_DATA]);
    if (decodedToken?.customer?.id) {
        try {
            jwt__default["default"].verify(req.cookies[COOKIE_KEY_CUSTOMER_DATA], devtoolsAppSecret);
            return decodedToken.customer.id;
        }
        catch (error) {
            if (error?.name === 'TokenExpiredError') {
                await performLogin(context, decodedToken.customer.id);
                const customerDataToken = await verifyLogin(context);
                setTokenCookie$1(context, customerDataToken);
                return decodedToken.customer.id;
            }
            throw { statusCode: 401, error };
        }
    }
    return null;
};

const getCustomers = async (context, params) => {
    const idFromCookie = await getCustomerIdFromCookie(context);
    if (idFromCookie) {
        return await context.client.v3.get(queryString__default["default"].stringifyUrl({
            url: BigCommerceEndpoints$1.customers,
            query: {
                ...params,
                'id:in': [idFromCookie]
            }
        }, {
            arrayFormat: 'comma'
        }));
    }
};
function getCustomerId(context, params) {
    const { config: { sdkSettings: { devtoolsAppSecret } }, req } = context;
    try {
        if (req.cookies[COOKIE_KEY_CUSTOMER_DATA]) {
            const decodedToken = jwt__default["default"].verify(req.cookies[COOKIE_KEY_CUSTOMER_DATA], devtoolsAppSecret);
            if (decodedToken?.customer?.id) {
                return decodedToken.customer.id;
            }
        }
        if ('id:in' in params &&
            Array.isArray(params['id:in']) &&
            params['id:in'].length) {
            return params['id:in'][0];
        }
    }
    catch (error) {
        throw new Error(error);
    }
    throw new Error('No customer ID');
}

function getEmbeddedCheckoutUrl(context, params) {
    try {
        const customerId = getCustomerId(context);
        if (customerId) {
            return generateSsoLoginLink(context, customerId, params.defaultEmbeddedCheckoutUrl);
        }
        return params.defaultEmbeddedCheckoutUrl;
    }
    catch (error) {
        return params.defaultEmbeddedCheckoutUrl;
    }
}

async function prepareEmbeddedCheckoutUrlOnResponse(context, response) {
    const { config: { sdkSettings: { guestToken } } } = context;
    let embeddedCheckoutUrl = response?.data?.redirect_urls?.embedded_checkout_url;
    if (embeddedCheckoutUrl) {
        embeddedCheckoutUrl = queryString__default["default"].stringifyUrl({
            url: embeddedCheckoutUrl,
            query: {
                ...(guestToken ? { guestTkn: guestToken } : {})
            }
        });
        response.data.redirect_urls.embedded_checkout_url = await getEmbeddedCheckoutUrl(context, {
            defaultEmbeddedCheckoutUrl: embeddedCheckoutUrl
        });
    }
}

const addCartItems = async (context, params) => {
    const { cartId, data, include } = params;
    // The list price needs to be removed on the API level, to cater for modified requests
    if (data?.custom_items) {
        data.custom_items = data.custom_items.map(item => {
            delete item.list_price;
            return item;
        });
    }
    if (data?.line_items) {
        data.line_items = data.line_items.map(item => {
            delete item.list_price;
            return item;
        });
    }
    const response = await context.client.v3.post(queryString__default["default"].stringifyUrl({
        url: BigCommerceEndpoints$1.cartItems(cartId),
        query: include ? { include } : undefined
    }), data);
    await prepareEmbeddedCheckoutUrlOnResponse(context, response);
    return response;
};

const createCart = async (context, params) => {
    const { data, include } = params;
    const idFromCookie = await getCustomerIdFromCookie(context);
    if (idFromCookie) {
        data.customer_id = idFromCookie;
    }
    // The list price needs to be removed on the API level, to cater for modified requests
    if (data?.custom_items) {
        data.custom_items = data.custom_items.map((item) => {
            delete item.list_price;
            return item;
        });
    }
    if (data?.line_items) {
        data.line_items = data.line_items.map((item) => {
            delete item.list_price;
            return item;
        });
    }
    const response = await context.client.v3.post(queryString__default["default"].stringifyUrl({
        url: BigCommerceEndpoints$1.cart(),
        query: include ? { include } : undefined
    }), data);
    await prepareEmbeddedCheckoutUrlOnResponse(context, response);
    return response;
};

const deleteCart = async (context, params) => {
    const { id } = params;
    return await context.client.v3.delete(queryString__default["default"].stringifyUrl({
        url: BigCommerceEndpoints$1.cart(id)
    }));
};

const getCart = async (context, params) => {
    const { id, include } = params;
    const response = await context.client.v3.get(queryString__default["default"].stringifyUrl({
        url: BigCommerceEndpoints$1.cart(id),
        query: include ? { include } : undefined
    }));
    await prepareEmbeddedCheckoutUrlOnResponse(context, response);
    return response;
};

const updateCart = async (context, params) => {
    const { id, include } = params;
    const idFromCookie = await getCustomerIdFromCookie(context);
    if (idFromCookie) {
        const payload = {
            customer_id: idFromCookie
        };
        const response = await context.client.v3.put(queryString__default["default"].stringifyUrl({
            url: BigCommerceEndpoints$1.cart(id),
            query: include ? { include } : undefined
        }), payload);
        await prepareEmbeddedCheckoutUrlOnResponse(context, response);
        return response;
    }
};

const removeCartItem = async (context, params) => {
    const { cartId, itemId, include } = params;
    const response = await context.client.v3.delete(queryString__default["default"].stringifyUrl({
        url: BigCommerceEndpoints$1.cartItems(cartId, itemId),
        query: include ? { include } : undefined
    }));
    await prepareEmbeddedCheckoutUrlOnResponse(context, response);
    return response;
};

const updateCartItem = async (context, params) => {
    const { cartId, itemId, include, data } = params;
    // The list price needs to be removed on the API level, to cater for modified requests
    if (data.line_item?.list_price) {
        delete data.line_item.list_price;
    }
    const response = await context.client.v3.put(queryString__default["default"].stringifyUrl({
        url: BigCommerceEndpoints$1.cartItems(cartId, itemId),
        query: include ? { include } : undefined
    }), data);
    await prepareEmbeddedCheckoutUrlOnResponse(context, response);
    return response;
};

var cart = /*#__PURE__*/Object.freeze({
  __proto__: null,
  addCartItems: addCartItems,
  createCart: createCart,
  deleteCart: deleteCart,
  getCart: getCart,
  updateCart: updateCart,
  removeCartItem: removeCartItem,
  updateCartItem: updateCartItem
});

/**
 *
 * @param context BigcommerceIntegrationContext
 * @returns CategoryTree array with children categories
 */
const getCategoryTree = async (context) => {
    const { categoryTree } = BigCommerceEndpoints$1;
    const response = await context.client.v3.get(categoryTree());
    return response;
};

const getCategory = async (context, params) => {
    const { categoryId } = params;
    if (!categoryId || typeof categoryId !== 'number') {
        throw new Error(`CategoryId with value: ${categoryId} is not valid. Use number value.`);
    }
    const response = await context.client.v3.get(BigCommerceEndpoints$1.category(categoryId));
    return response;
};

var categories = /*#__PURE__*/Object.freeze({
  __proto__: null,
  getCategoryTree: getCategoryTree,
  getCategory: getCategory
});

const createCustomer = async (context, params) => {
    checkParameters(params);
    params.authentication = {
        new_password: params.password
    };
    const payload = {
        authentication: params.authentication,
        email: params.email,
        password: params.password,
        first_name: params.first_name,
        last_name: params.last_name,
        company: params.company,
        phone: params.phone,
        accepts_product_review_abandoned_cart_emails: params.accepts_product_review_abandoned_cart_emails,
        channel_ids: params.channel_ids,
        custom_fields: params.custom_fields
    };
    const { data } = await context.client.v3.post(BigCommerceEndpoints$1.customers, [payload]);
    setTokenCookie(context, data[0]);
    return data[0];
};
function checkParameters(params) {
    if (!params.first_name ||
        !params.last_name ||
        !params.email ||
        !params.password ||
        !Array.isArray(params.custom_fields)) {
        throw new Error('Required parameters missing.');
    }
}
function setTokenCookie(context, customerData) {
    const { config: { jwtTokenExpirationDays, secureCookies, sdkSettings: { secret } }, res } = context;
    const { id, email, customer_group_id: groupId } = customerData;
    const payload = {
        customer: {
            id,
            email,
            group_id: groupId
        }
    };
    const token = jwt__default["default"].sign(payload, secret, {
        algorithm: 'HS256'
    });
    res.cookie(COOKIE_KEY_CUSTOMER_DATA, token, {
        expires: getDateDaysLater(jwtTokenExpirationDays),
        httpOnly: secureCookies,
        secure: secureCookies,
        sameSite: secureCookies ? 'Strict' : 'Lax'
    });
}

const logoutCustomer = (context) => {
    const { config: { secureCookies }, res } = context;
    const cookieOptions = {
        httpOnly: secureCookies,
        secure: secureCookies,
        sameSite: secureCookies ? 'Strict' : 'Lax',
        maxAge: 0
    };
    res.cookie(COOKIE_KEY_CUSTOMER_DATA, '', cookieOptions);
    res.cookie(COOKIE_KEY_SHOP_SESSION_TOKEN, '', cookieOptions);
    res.cookie(COOKIE_KEY_SHOPPER_PREF, '', cookieOptions);
};

const updateCustomer = async (context, params) => {
    const idFromCookie = await getCustomerIdFromCookie(context);
    if (idFromCookie && params.validation) {
        const payload = {
            validation: {
                ...params.validation,
                channel_id: Number(process.env.BIGCOMMERCE_CHANNEL_ID) || 1
            }
        };
        const validation = await validateCredentials(context, payload.validation);
        if (!validation.is_valid) {
            const errorMessage = 'Invalid credentials';
            throw { statusCode: 403, message: errorMessage };
        }
        if (params.accepts_product_review_abandoned_cart_emails !== undefined) {
            payload.accepts_product_review_abandoned_cart_emails = params.accepts_product_review_abandoned_cart_emails;
        }
        if (params.email) {
            payload.email = params.email;
        }
        if (params.first_name) {
            payload.first_name = params.first_name;
        }
        if (params.last_name) {
            payload.last_name = params.last_name;
        }
        if (params.company) {
            payload.company = params.company;
        }
        if (params.phone) {
            payload.phone = params.phone;
        }
        if (params.authentication) {
            payload.authentication = params.authentication;
        }
        return await context.client.v3.put(queryString__default["default"].stringifyUrl({
            url: BigCommerceEndpoints$1.customers
        }), [{
                ...payload,
                id: idFromCookie
            }]);
    }
};

const updateCustomerFormFields = async (context, params) => {
    const { data } = params;
    const idFromCookie = await getCustomerIdFromCookie(context);
    if (data?.length > 0 && idFromCookie) {
        data.forEach((item) => item.customer_id = idFromCookie);
        return await context.client.v3.put(BigCommerceEndpoints$1.formFieldValues, data);
    }
};

var customers = /*#__PURE__*/Object.freeze({
  __proto__: null,
  getCustomers: getCustomers,
  createCustomer: createCustomer,
  loginCustomer: loginCustomer,
  logoutCustomer: logoutCustomer,
  updateCustomer: updateCustomer,
  updateCustomerFormFields: updateCustomerFormFields,
  validateCredentials: validateCredentials
});

const getProducts = async (context, params) => {
    if (params.include && !params.include.includes('images')) {
        params.include = params.include.concat(',images');
    }
    else if (!params.include) {
        params.include = 'images';
    }
    params.is_visible = params.is_visible ?? true;
    return await context.client.v3.get(queryString__default["default"].stringifyUrl({
        url: BigCommerceEndpoints$1.products,
        query: { ...params }
    }, {
        arrayFormat: 'comma'
    }));
};

const getProductReview = async (context, props) => {
    const { productId, reviewId } = props;
    if (!productId || typeof productId !== 'number')
        throw Error(`ProductId with value: ${productId} is not valid. Use number value.`);
    if (!reviewId || typeof reviewId !== 'number')
        throw Error(`ReviewId with value: ${reviewId} is not valid. Use number value.`);
    return context.client.v3.get(BigCommerceEndpoints$1.review(productId, reviewId));
};

const getProductReviewCollection = async (context, props, query) => {
    const { productId } = props;
    if (!productId || typeof productId !== 'number')
        throw Error(`ProductId with value: ${productId} is not valid. Use number value.`);
    return context.client.v3.get(queryString.stringifyUrl({
        url: BigCommerceEndpoints$1.reviews(productId),
        query: { ...query }
    }));
};

var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

var dayjs_min = {exports: {}};

(function (module, exports) {
!function(t,e){module.exports=e();}(commonjsGlobal,(function(){var t=1e3,e=6e4,n=36e5,r="millisecond",i="second",s="minute",u="hour",a="day",o="week",f="month",h="quarter",c="year",d="date",$="Invalid Date",l=/^(\d{4})[-/]?(\d{1,2})?[-/]?(\d{0,2})[Tt\s]*(\d{1,2})?:?(\d{1,2})?:?(\d{1,2})?[.:]?(\d+)?$/,y=/\[([^\]]+)]|Y{1,4}|M{1,4}|D{1,2}|d{1,4}|H{1,2}|h{1,2}|a|A|m{1,2}|s{1,2}|Z{1,2}|SSS/g,M={name:"en",weekdays:"Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),months:"January_February_March_April_May_June_July_August_September_October_November_December".split("_")},m=function(t,e,n){var r=String(t);return !r||r.length>=e?t:""+Array(e+1-r.length).join(n)+t},g={s:m,z:function(t){var e=-t.utcOffset(),n=Math.abs(e),r=Math.floor(n/60),i=n%60;return (e<=0?"+":"-")+m(r,2,"0")+":"+m(i,2,"0")},m:function t(e,n){if(e.date()<n.date())return -t(n,e);var r=12*(n.year()-e.year())+(n.month()-e.month()),i=e.clone().add(r,f),s=n-i<0,u=e.clone().add(r+(s?-1:1),f);return +(-(r+(n-i)/(s?i-u:u-i))||0)},a:function(t){return t<0?Math.ceil(t)||0:Math.floor(t)},p:function(t){return {M:f,y:c,w:o,d:a,D:d,h:u,m:s,s:i,ms:r,Q:h}[t]||String(t||"").toLowerCase().replace(/s$/,"")},u:function(t){return void 0===t}},D="en",v={};v[D]=M;var p=function(t){return t instanceof _},S=function(t,e,n){var r;if(!t)return D;if("string"==typeof t)v[t]&&(r=t),e&&(v[t]=e,r=t);else {var i=t.name;v[i]=t,r=i;}return !n&&r&&(D=r),r||!n&&D},w=function(t,e){if(p(t))return t.clone();var n="object"==typeof e?e:{};return n.date=t,n.args=arguments,new _(n)},O=g;O.l=S,O.i=p,O.w=function(t,e){return w(t,{locale:e.$L,utc:e.$u,x:e.$x,$offset:e.$offset})};var _=function(){function M(t){this.$L=S(t.locale,null,!0),this.parse(t);}var m=M.prototype;return m.parse=function(t){this.$d=function(t){var e=t.date,n=t.utc;if(null===e)return new Date(NaN);if(O.u(e))return new Date;if(e instanceof Date)return new Date(e);if("string"==typeof e&&!/Z$/i.test(e)){var r=e.match(l);if(r){var i=r[2]-1||0,s=(r[7]||"0").substring(0,3);return n?new Date(Date.UTC(r[1],i,r[3]||1,r[4]||0,r[5]||0,r[6]||0,s)):new Date(r[1],i,r[3]||1,r[4]||0,r[5]||0,r[6]||0,s)}}return new Date(e)}(t),this.$x=t.x||{},this.init();},m.init=function(){var t=this.$d;this.$y=t.getFullYear(),this.$M=t.getMonth(),this.$D=t.getDate(),this.$W=t.getDay(),this.$H=t.getHours(),this.$m=t.getMinutes(),this.$s=t.getSeconds(),this.$ms=t.getMilliseconds();},m.$utils=function(){return O},m.isValid=function(){return !(this.$d.toString()===$)},m.isSame=function(t,e){var n=w(t);return this.startOf(e)<=n&&n<=this.endOf(e)},m.isAfter=function(t,e){return w(t)<this.startOf(e)},m.isBefore=function(t,e){return this.endOf(e)<w(t)},m.$g=function(t,e,n){return O.u(t)?this[e]:this.set(n,t)},m.unix=function(){return Math.floor(this.valueOf()/1e3)},m.valueOf=function(){return this.$d.getTime()},m.startOf=function(t,e){var n=this,r=!!O.u(e)||e,h=O.p(t),$=function(t,e){var i=O.w(n.$u?Date.UTC(n.$y,e,t):new Date(n.$y,e,t),n);return r?i:i.endOf(a)},l=function(t,e){return O.w(n.toDate()[t].apply(n.toDate("s"),(r?[0,0,0,0]:[23,59,59,999]).slice(e)),n)},y=this.$W,M=this.$M,m=this.$D,g="set"+(this.$u?"UTC":"");switch(h){case c:return r?$(1,0):$(31,11);case f:return r?$(1,M):$(0,M+1);case o:var D=this.$locale().weekStart||0,v=(y<D?y+7:y)-D;return $(r?m-v:m+(6-v),M);case a:case d:return l(g+"Hours",0);case u:return l(g+"Minutes",1);case s:return l(g+"Seconds",2);case i:return l(g+"Milliseconds",3);default:return this.clone()}},m.endOf=function(t){return this.startOf(t,!1)},m.$set=function(t,e){var n,o=O.p(t),h="set"+(this.$u?"UTC":""),$=(n={},n[a]=h+"Date",n[d]=h+"Date",n[f]=h+"Month",n[c]=h+"FullYear",n[u]=h+"Hours",n[s]=h+"Minutes",n[i]=h+"Seconds",n[r]=h+"Milliseconds",n)[o],l=o===a?this.$D+(e-this.$W):e;if(o===f||o===c){var y=this.clone().set(d,1);y.$d[$](l),y.init(),this.$d=y.set(d,Math.min(this.$D,y.daysInMonth())).$d;}else $&&this.$d[$](l);return this.init(),this},m.set=function(t,e){return this.clone().$set(t,e)},m.get=function(t){return this[O.p(t)]()},m.add=function(r,h){var d,$=this;r=Number(r);var l=O.p(h),y=function(t){var e=w($);return O.w(e.date(e.date()+Math.round(t*r)),$)};if(l===f)return this.set(f,this.$M+r);if(l===c)return this.set(c,this.$y+r);if(l===a)return y(1);if(l===o)return y(7);var M=(d={},d[s]=e,d[u]=n,d[i]=t,d)[l]||1,m=this.$d.getTime()+r*M;return O.w(m,this)},m.subtract=function(t,e){return this.add(-1*t,e)},m.format=function(t){var e=this,n=this.$locale();if(!this.isValid())return n.invalidDate||$;var r=t||"YYYY-MM-DDTHH:mm:ssZ",i=O.z(this),s=this.$H,u=this.$m,a=this.$M,o=n.weekdays,f=n.months,h=function(t,n,i,s){return t&&(t[n]||t(e,r))||i[n].substr(0,s)},c=function(t){return O.s(s%12||12,t,"0")},d=n.meridiem||function(t,e,n){var r=t<12?"AM":"PM";return n?r.toLowerCase():r},l={YY:String(this.$y).slice(-2),YYYY:this.$y,M:a+1,MM:O.s(a+1,2,"0"),MMM:h(n.monthsShort,a,f,3),MMMM:h(f,a),D:this.$D,DD:O.s(this.$D,2,"0"),d:String(this.$W),dd:h(n.weekdaysMin,this.$W,o,2),ddd:h(n.weekdaysShort,this.$W,o,3),dddd:o[this.$W],H:String(s),HH:O.s(s,2,"0"),h:c(1),hh:c(2),a:d(s,u,!0),A:d(s,u,!1),m:String(u),mm:O.s(u,2,"0"),s:String(this.$s),ss:O.s(this.$s,2,"0"),SSS:O.s(this.$ms,3,"0"),Z:i};return r.replace(y,(function(t,e){return e||l[t]||i.replace(":","")}))},m.utcOffset=function(){return 15*-Math.round(this.$d.getTimezoneOffset()/15)},m.diff=function(r,d,$){var l,y=O.p(d),M=w(r),m=(M.utcOffset()-this.utcOffset())*e,g=this-M,D=O.m(this,M);return D=(l={},l[c]=D/12,l[f]=D,l[h]=D/3,l[o]=(g-m)/6048e5,l[a]=(g-m)/864e5,l[u]=g/n,l[s]=g/e,l[i]=g/t,l)[y]||g,$?D:O.a(D)},m.daysInMonth=function(){return this.endOf(f).$D},m.$locale=function(){return v[this.$L]},m.locale=function(t,e){if(!t)return this.$L;var n=this.clone(),r=S(t,e,!0);return r&&(n.$L=r),n},m.clone=function(){return O.w(this.$d,this)},m.toDate=function(){return new Date(this.valueOf())},m.toJSON=function(){return this.isValid()?this.toISOString():null},m.toISOString=function(){return this.$d.toISOString()},m.toString=function(){return this.$d.toUTCString()},M}(),b=_.prototype;return w.prototype=b,[["$ms",r],["$s",i],["$m",s],["$H",u],["$W",a],["$M",f],["$y",c],["$D",d]].forEach((function(t){b[t[1]]=function(e){return this.$g(e,t[0],t[1])};})),w.extend=function(t,e){return t.$i||(t(e,_,w),t.$i=!0),w},w.locale=S,w.isDayjs=p,w.unix=function(t){return w(1e3*t)},w.en=v[D],w.Ls=v,w.p={},w}));
}(dayjs_min));

var dayjs = dayjs_min.exports;

const createProductReview = async (context, props) => {
    const { title, productId } = props;
    if (!productId || typeof productId !== 'number')
        throw Error(`ProductId with value: ${productId} is not valid. Use number value.`);
    if (!title || typeof title !== 'string')
        throw Error(`Title with value: ${title} is not valid. Use string value.`);
    // Product id is not required in the CREATE product review props, just to get correct endpoint.
    delete props.productId;
    return context.client.v3.post(BigCommerceEndpoints$1.reviews(productId), {
        ...props,
        date_reviewed: dayjs().format('YYYY-MM-DDTHH:mm:ssZ')
    });
};

var review = /*#__PURE__*/Object.freeze({
  __proto__: null,
  getProductReview: getProductReview,
  getProductReviewCollection: getProductReviewCollection,
  createProductReview: createProductReview
});

const createWishlist = async (context, props) => {
    const { name } = props;
    const customerId = await getCustomerIdFromCookie(context);
    if (!name || typeof name !== 'string') {
        throw Error(`Name with value: ${name} is not valid. Use string value.`);
    }
    if (!customerId || typeof customerId !== 'number') {
        throw Error(`Customer ID with value: ${customerId} is not valid.`);
    }
    return context.client.v3.post(BigCommerceEndpoints$1.wishlists(), {
        ...props,
        customer_id: customerId
    });
};

const getAllWishlists = async (context, query) => {
    const customerId = await getCustomerIdFromCookie(context);
    if (!customerId || typeof customerId !== 'number') {
        throw Error(`Customer ID with value: ${customerId} is not valid.`);
    }
    return context.client.v3.get(queryString.stringifyUrl({
        url: BigCommerceEndpoints$1.wishlists(),
        query: {
            ...query,
            customer_id: customerId
        }
    }));
};

const addWishlistItems = async (context, params) => {
    const { wishlistId, items } = params;
    if (!wishlistId || typeof wishlistId !== 'number') {
        throw Error(`Wishlist id with value: ${wishlistId} is not valid. Use number value.`);
    }
    if (!items || !items.length) {
        throw Error(`Wishlist items with value: ${items} are not valid. Use non-empty array of wishlist items.`);
    }
    const addWishlistItemParams = { items: params.items };
    return context.client.v3.post(BigCommerceEndpoints$1.wishlistItems(wishlistId), addWishlistItemParams);
};

const removeWishlistItem = async (context, params) => {
    const { wishlistId, itemId } = params;
    if (!wishlistId || typeof wishlistId !== 'number') {
        throw Error(`Wishlist id with value: ${wishlistId} is not valid. Use number value.`);
    }
    if (!itemId || typeof itemId !== 'number') {
        throw Error(`Item id with value: ${itemId} is not valid. Use number value.`);
    }
    return await context.client.v3.delete(BigCommerceEndpoints$1.wishlistItems(wishlistId, itemId));
};

const deleteWishlist = async (context, wishlistId) => {
    if (!wishlistId || typeof wishlistId !== 'number') {
        throw Error(`Wishlist id with value: ${wishlistId} is not valid. Use number value.`);
    }
    return await context.client.v3.delete(BigCommerceEndpoints$1.wishlists(wishlistId));
};

var wishlist = /*#__PURE__*/Object.freeze({
  __proto__: null,
  createWishlist: createWishlist,
  getAllWishlists: getAllWishlists,
  addWishlistItems: addWishlistItems,
  removeWishlistItem: removeWishlistItem,
  deleteWishlist: deleteWishlist
});

const createCustomerAddress = async (context, params) => {
    if (params?.address1?.length > 255 || params?.address2?.length > 255) {
        throw new Error('Address line 1 and line 2 must be 255 characters or less.');
    }
    return await context.client.v3.post(BigCommerceEndpoints$1.addresses, [{
            ...params,
            customer_id: await getCustomerIdFromCookie(context)
        }]);
};

const getCustomerAddress = async (context, params) => {
    const idFromCookie = await getCustomerIdFromCookie(context);
    if (idFromCookie) {
        return await context.client.v3.get(queryString__default["default"].stringifyUrl({
            url: BigCommerceEndpoints$1.addresses,
            query: {
                ...params,
                'customer_id:in': [idFromCookie]
            }
        }, {
            arrayFormat: 'comma'
        }));
    }
};

const deleteCustomerAddress = async (context, params) => {
    const { data: ownAddresses } = await getCustomerAddress(context, {});
    if (!ownAddresses.find(address => address.id === params['id:in'][0])) {
        throw new Error('You can delete your own address only.');
    }
    return await context.client.v3.delete(queryString__default["default"].stringifyUrl({
        url: BigCommerceEndpoints$1.addresses,
        query: { ...params }
    }, {
        arrayFormat: 'comma'
    }));
};

const updateCustomerAddress = async (context, params) => {
    const { data: ownAddresses } = await getCustomerAddress(context, {});
    if (!ownAddresses.find(address => address.id === params.id)) {
        throw new Error('You can edit your own address only.');
    }
    if (params?.address1?.length > 255 || params?.address2?.length > 255) {
        throw new Error('Address line 1 and line 2 must be 255 characters or less.');
    }
    return await context.client.v3.put(queryString__default["default"].stringifyUrl({
        url: BigCommerceEndpoints$1.addresses
    }), [{
            ...params,
            customer_id: await getCustomerIdFromCookie(context)
        }]);
};

var address = /*#__PURE__*/Object.freeze({
  __proto__: null,
  createCustomerAddress: createCustomerAddress,
  deleteCustomerAddress: deleteCustomerAddress,
  getCustomerAddress: getCustomerAddress,
  updateCustomerAddress: updateCustomerAddress
});

const getOrders = async (context, params) => {
    const idFromCookie = await getCustomerIdFromCookie(context);
    if (idFromCookie) {
        return await context.client.v2.get(queryString.stringifyUrl({
            url: BigCommerceEndpoints$1.orders,
            query: {
                ...params,
                channel_id: Number(process.env.BIGCOMMERCE_CHANNEL_ID) || 1,
                customer_id: await getCustomerIdFromCookie(context)
            }
        }));
    }
};

const getOrderProducts = async (context, params) => {
    const { orderId, ...queryParams } = params;
    const idFromCookie = await getCustomerIdFromCookie(context);
    if (idFromCookie) {
        const customerOrders = await getOrders(context);
        const customerExistingOrdersIds = customerOrders.map(order => order.id);
        if (customerExistingOrdersIds.includes(orderId)) {
            if (!orderId || typeof orderId !== 'number') {
                throw Error(`Order id with value: ${orderId} is not valid. Use number value.`);
            }
            return await context.client.v2.get(queryString.stringifyUrl({
                url: BigCommerceEndpoints$1.orderProducts(orderId),
                query: { ...queryParams }
            }));
        }
    }
};

const getOrderShippingAddresses = async (context, params) => {
    const { orderId, ...queryParams } = params;
    if (!orderId || typeof orderId !== 'number') {
        throw Error(`Order id with value: ${orderId} is not valid. Use number value.`);
    }
    return await context.client.v2.get(queryString.stringifyUrl({
        url: BigCommerceEndpoints$1.orderShipping(orderId),
        query: { ...queryParams }
    }));
};

const getOrderByCart = async (context, params) => {
    const orders = await context.client.v2.get(queryString.stringifyUrl({
        url: BigCommerceEndpoints$1.orders,
        query: {
            cart_id: params.cartId
        }
    }));
    if (orders?.length) {
        const order = orders[0];
        const products = await getOrderProducts(context, { orderId: order.id });
        const shippingAddresses = await getOrderShippingAddresses(context, {
            orderId: order.id
        });
        return {
            ...order,
            products,
            shipping_addresses: shippingAddresses
        };
    }
    throw new Error('No order found');
};

var order = /*#__PURE__*/Object.freeze({
  __proto__: null,
  getOrders: getOrders,
  getOrderProducts: getOrderProducts,
  getOrderByCart: getOrderByCart
});

const endpoints = {
    ...cart,
    ...categories,
    ...customers,
    getProducts,
    ...review,
    ...wishlist,
    ...address,
    ...order
};
var api = endpoints;

const onCreate = (settings) => {
    settings.sdkSettings.storeUrl = settings.sdkSettings.storeUrl.replace(/\/$/, '');
    return {
        config: settings,
        client: {
            v2: client({
                ...settings.sdkSettings,
                apiVersion: 'v2'
            }),
            v3: client({
                ...settings.sdkSettings,
                apiVersion: 'v3'
            })
        }
    };
};
const { createApiClient } = core.apiClientFactory({
    onCreate,
    api
});

exports.createApiClient = createApiClient;
//# sourceMappingURL=index.js.map
